@@ -36,7 +36,7 @@ def export_avatar(
     data = json.dumps(params)
 
     # save JSON params to file
-    with open(os.path.join(TASK_PARAMS_FILE_NAME, plugin_path), 'w') as outfile:
+    with open(os.path.join(work_path, TASK_PARAMS_FILE_NAME), 'w') as outfile:
         json.dump(data, outfile)
 
     # launch VStitcher
